==> gradle-2.2-rc-1-src.zip: gradle-2.2-rc-1/subprojects/model-core/src/test/groovy/org/gradle/model/internal/inspect/OuterClass.java <==
/*
 * Copyright 2013 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.model.internal.inspect;

@SuppressWarnings("UnusedDeclaration")
public class OuterClass {
    public static abstract class AbstractClass {
    }

    public static interface AnInterface {
    }

    public class InnerInstanceClass {
    }

    private class PrivateInnerStaticClass {
    }

    public static class HasSuperclass extends InnerPublicStaticClass {
    }

    public static class HasTwoConstructors {
        public HasTwoConstructors() {
        }

        public HasTwoConstructors(String arg) {
        }
    }

    public static class HasInstanceVar {
        private String foo;
    }

    public static class HasFinalInstanceVar {
        private final String foo = null;
    }

    public static class HasNonFinalStaticVar {
        private static String foo;
    }

    public static class InnerPublicStaticClass {
    }

    public static class HasExplicitDefaultConstructor {
        public HasExplicitDefaultConstructor() {
        }
    }

    public static class HasStaticFinalField {
        private static final Object VALUE = null;
    }
}

==> gradle-2.5-rc-2-src.zip: gradle-2.5-rc-2/subprojects/model-core/src/test/groovy/org/gradle/model/internal/inspect/OuterClass.java <==
/*
 * Copyright 2013 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.model.internal.inspect;

import org.gradle.model.RuleSource;

@SuppressWarnings("UnusedDeclaration")
public class OuterClass {
    public static abstract class AbstractClass extends RuleSource {
    }

    public static interface AnInterface {
    }

    public class InnerInstanceClass extends RuleSource {
    }

    private class PrivateInnerStaticClass {
    }

    public static class HasSuperclass extends InnerPublicStaticClass {
    }

    public static class DoesNotExtendRuleSource {
    }

    public static class HasTwoConstructors extends RuleSource {
        public HasTwoConstructors() {
        }

        public HasTwoConstructors(String arg) {
        }
    }

    public static class HasInstanceVar extends RuleSource {
        private String foo;
    }

    public static class HasFinalInstanceVar extends RuleSource {
        private final String foo = null;
    }

    public static class HasNonFinalStaticVar extends RuleSource {
        private static String foo;
    }

    public static class InnerPublicStaticClass extends RuleSource {
    }

    public static class HasExplicitDefaultConstructor extends RuleSource {
        public HasExplicitDefaultConstructor() {
        }
    }

    public static class HasStaticFinalField extends RuleSource {
        private static final Object VALUE = null;
    }
}
